==> payara-embedded-all-4.1.1.171-sources.jar: fish/payara/micro/cmd/options/IntegerValidator.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2016 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.micro.cmd.options;

import java.text.MessageFormat;

/**
 *
 * @author steve
 */
public class IntegerValidator extends Validator {
    
    int minimumValue = Integer.MIN_VALUE;
    int maxValue = Integer.MAX_VALUE;
    boolean rangeSet = false;

    public IntegerValidator() {
    }
    
    public IntegerValidator(int minimumVal, int maxValue) {
        minimumValue = minimumVal;
        this.maxValue = maxValue;
        rangeSet = true;
    }
    

    @Override
    boolean validate(String optionValue) throws ValidationException {
        try {
            int value = Integer.parseInt(optionValue);
            if (value < minimumValue || value > maxValue) {
                throw new NumberFormatException();
            }
        }catch (NumberFormatException nfe) {
            if (rangeSet) {
                throw new ValidationException(MessageFormat.format(RuntimeOptions.bundle.getString("integerRangeIncorrect"),optionValue,minimumValue,maxValue));
            } else {
                throw new ValidationException(MessageFormat.format(RuntimeOptions.bundle.getString("integerIncorrect"),optionValue));                
            }
        }
        return true;
    }
    
}

==> payara-embedded-all-6.2023.2-sources.jar: fish/payara/micro/cmd/options/IntegerValidator.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2016 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.micro.cmd.options;

import java.text.MessageFormat;

/**
 *
 * @author steve
 */
public class IntegerValidator extends Validator {
    
    int minimumValue = Integer.MIN_VALUE;
    int maxValue = Integer.MAX_VALUE;
    boolean rangeSet = false;

    public IntegerValidator() {
    }
    
    public IntegerValidator(int minimumVal, int maxValue) {
        minimumValue = minimumVal;
        this.maxValue = maxValue;
        rangeSet = true;
    }
    

    @Override
    boolean validate(String optionValue) throws ValidationException {
        try {
            int value = Integer.parseInt(optionValue);
            if (value < minimumValue || value > maxValue) {
                throw new NumberFormatException();
            }
        }catch (NumberFormatException nfe) {
            if (rangeSet) {
                throw new ValidationException(MessageFormat.format(RuntimeOptions.commandlogstrings.getString("integerRangeIncorrect"),optionValue,minimumValue,maxValue));
            } else {
                throw new ValidationException(MessageFormat.format(RuntimeOptions.commandlogstrings.getString("integerIncorrect"),optionValue));                
            }
        }
        return true;
    }
    
}
